@@ -1,5 +1,5 @@
 from .registered_task import RegisteredTask, MockTask, PrintTask
-from .taskqueue import TaskQueue, MockTaskQueue
+from .taskqueue import TaskQueue, MockTaskQueue, LocalTaskQueue
 from .secrets import (
   QUEUE_NAME, TEST_QUEUE_NAME, QUEUE_TYPE, 
   PROJECT_NAME, APPENGINE_QUEUE_URL
